#!/usr/bin/python

def transform_xmllint(file, xsl_file, output, params = {}):
	import libxml2
	import libxslt

	new_params = {}
	keys = params.keys()
	for key in keys:
		new_params[key] = '"%s"' % params[key]
	params = new_params

	xml_doc = file
	# parse stylesheet
	styledoc = libxml2.parseFile(xsl_file)
	style = libxslt.parseStylesheetDoc(styledoc)
	# parse doc
	doc = libxml2.parseFile(xml_doc)
	result = style.applyStylesheet(doc, params)
	style.saveResultToFilename(output, result, 0)
	rstr = str(result)
	style.freeStylesheet()
	doc.freeDoc()
	result.freeDoc()
	return rstr

def transform_xmllint_mem(in_str, xsl_file, output, params = {}):
	import libxml2
	import libxslt

	new_params = {}
	keys = params.keys()
	for key in keys:
		new_params[key] = '"%s"' % params[key]
	params = new_params

	# parse stylesheet
	styledoc = libxml2.parseFile(xsl_file)
	style = libxslt.parseStylesheetDoc(styledoc)
	# parse doc
	doc = libxml2.parseMemory(in_str, len(in_str))
	result = style.applyStylesheet(doc, params)
	style.saveResultToFilename(output, result, 0)
	rstr = str(result)
	style.freeStylesheet()
	doc.freeDoc()
	result.freeDoc()
	return rstr

import glob

xml_files = [ i[6:] for i in glob.glob('inbox/*___XML___*.xml') ]
html_files = [ i[5:] for i in glob.glob('html/*___XML___*.html') ]
do_regen = False

for xml_file in xml_files:
	html_file = xml_file[:-3] + "html"
	if not html_file in html_files:
		xsl_file = ""
		print "Gererating " + html_file 
		if  "___XML___Configure" in html_file:
			xsl_file = "configure.xsl"
		elif  "___XML___Build" in html_file:
			xsl_file = "build.xsl"
		elif  "___XML___Test" in html_file:
			xsl_file = "test.xsl"
		else:
			print "No xsl file for " + xml_file
			continue
		do_regen = True
		transform_xmllint("inbox/" + xml_file, xsl_file, "html/" + html_file)			

#
# Regenerate the overview page if any new entries has been generated
#

from sets import Set

if do_regen:
	bxml = "<?xml version='1.0' encoding='UTF-8'?>\n"
	bxml += "<builds>"
	roots = Set([i[:(i.find('___XML___')+9)] for i in xml_files])
	for i in roots:
		# parse the timestamp
		k = i.find("___", i.find("___")+1)+3
		time = i[k:k+13]
		# construct the build info
		bxml += "<build>"
		bxml += "<name>inbox/" + i + "</name>";
		bxml += "<timestamp>" + time + "</timestamp>"
		bxml += "</build>"
	bxml += "</builds>"
	transform_xmllint_mem(bxml, "./overview.xsl", "html/overview.html")
	
#transform_xmllint("./builds.xml", "./overview.xsl", "overview.html")
#transform_xmllint("./jcd-t60p___Linux-c++___20061227-1054-Experimental___XML___Configure.xml", "./configure.xsl", "configure.html")
#transform_xmllint("./jcd-t60p___Linux-c++___20061227-1054-Experimental___XML___Build.xml", "./build.xsl", "build.html")
#transform_xmllint("./jcd-t60p___Linux-c++___20061227-1054-Experimental___XML___Test.xml", "./test.xsl", "test.html")

