<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:include href="common.xsl"/>

<xsl:template match="/">
  <html>
  <head>
    <xsl:apply-templates select="document('head.xml')/common-head"/>
  </head>
  <body>
    <h1>CDashboard</h1>

    <div class="breadcrumb">Overview</div>

    <table class="overview">
	<tr><th>Project</th><th>Time</th><th>Site</th><th>Type</th><th>Configure</th><th>Build</th><th>Tests</th></tr>
	<xsl:for-each select="builds/build">
	<xsl:sort select="timestamp" order="descending"/>
	<tr>
	    <xsl:apply-templates select="document(concat(name,'Configure.xml'))/Site"/>
	    <xsl:apply-templates select="document(concat(name,'Configure.xml'))/Site/Configure/ConfigureStatus"/>
	    <xsl:apply-templates select="document(concat(name,'Build.xml'))/Site/Build"/>
	    <xsl:apply-templates select="document(concat(name,'Test.xml'))/Site/Testing"/>
	</tr>
	</xsl:for-each>
    </table>	
  </body>
  </html>
</xsl:template>

<xsl:template match="ConfigureStatus">
	<xsl:choose>
	<xsl:when test=". &gt; 0">
	  <td class="status-alert"><a>
	<xsl:attribute name="href"><xsl:value-of select="/Site/@Name"/>___<xsl:value-of select="/Site/@BuildName"/>___<xsl:value-of select="/Site/@BuildStamp"/>___XML___Configure.html</xsl:attribute>
Error: <xsl:value-of select="."/></a></td>
	</xsl:when>
	<xsl:otherwise>
	  <td class="status-ok">
	<xsl:attribute name="onclick">document.location='<xsl:value-of select="/Site/@Name"/>___<xsl:value-of select="/Site/@BuildName"/>___<xsl:value-of select="/Site/@BuildStamp"/>___XML___Configure.html'</xsl:attribute>
</td>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="Site">
	<td><xsl:value-of select="@BuildName"/></td>
	<td><xsl:value-of select="substring(@BuildStamp, 1, 13)"/></td>
	<td><xsl:value-of select="@Name"/></td>
	<td><xsl:value-of select="substring(@BuildStamp,15)"/></td>
</xsl:template>

<xsl:template match="Testing">
	<xsl:choose>
	<xsl:when test="count(Test[@Status != 'passed']) != 0">
	  <td class="status-alert"><a>
	<xsl:attribute name="href"><xsl:value-of select="/Site/@Name"/>___<xsl:value-of select="/Site/@BuildName"/>___<xsl:value-of select="/Site/@BuildStamp"/>___XML___Test.html</xsl:attribute>
	     <xsl:value-of select="count(Test[@Status != 'passed'])"/> of <xsl:value-of select="count(Test)"/> failed</a>
	  </td>
	</xsl:when>
	<xsl:otherwise>
	  <td class="status-ok">
	<xsl:attribute name="onclick">document.location='<xsl:value-of select="/Site/@Name"/>___<xsl:value-of select="/Site/@BuildName"/>___<xsl:value-of select="/Site/@BuildStamp"/>___XML___Test.html'</xsl:attribute>
</td>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="Build">
	<xsl:choose>
	<xsl:when test="count(Error) != 0">
	  <td class="status-alert"><a>
	<xsl:attribute name="href"><xsl:value-of select="/Site/@Name"/>___<xsl:value-of select="/Site/@BuildName"/>___<xsl:value-of select="/Site/@BuildStamp"/>___XML___Build.html</xsl:attribute>
	<xsl:value-of select="count(Error)"/> Errors</a></td>
	</xsl:when>
	<xsl:otherwise>
	  <td class="status-ok">
	<xsl:attribute name="onclick">document.location='<xsl:value-of select="/Site/@Name"/>___<xsl:value-of select="/Site/@BuildName"/>___<xsl:value-of select="/Site/@BuildStamp"/>___XML___Build.html'</xsl:attribute>
</td>
	</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
